@@ -1,6 +1,6 @@
 package ExtUtils::Config;
 {
-  $ExtUtils::Config::VERSION = '0.005';
+  $ExtUtils::Config::VERSION = '0.006';
 }
 
 use strict;
@@ -14,6 +14,11 @@ sub new {
 	}, $pack;
 }
 
+sub clone {
+	my $self = shift;
+	return __PACKAGE__->new($self->{values});
+}
+
 sub get {
 	my ($self, $key) = @_;
 	return exists $self->{values}{$key} ? $self->{values}{$key} : $Config{$key};
@@ -56,7 +61,7 @@ ExtUtils::Config - A wrapper for perl's configuration
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -79,7 +84,7 @@ Get the value of C<$key>. If not overriden it will return the value in %Config.
 
 =head2 exists($key)
 
-Tests for the existence of $key in either .
+Tests for the existence of $key.
 
 =head2 set($key, $value)
 
@@ -97,6 +102,10 @@ Get a hashref of all overridden values.
 
 Get a hashref of the complete configuration, including overrides.
 
+=head2 clone
+
+Clone the current configuration object.
+
 =head1 AUTHORS
 
 =over 4
